/*
 
Copyright (C) NEC Corporation 2012-2013. All Rights Reserved. 
Copyright (C) NEC Soft, Ltd. 2012-2013. All Rights Reserved. 
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.necsoft.hinemos.webclient.common;

public class Constants {

    public static final int EVENT_ROW_NUM = 100;

    public static final int MONITOR_SCOPE_ROW_NUM = 1000;

    public static final int MONITOR_STATUS_ROW_NUM = 1000;
    
    //max table row num for repository
    public static final int MAX_TABLE_ROW_NUM = 1000;

    // Set name of repository filter node properties
    public static final String NODE_FILTER_PROPERTIES = "node_filter_properties";
    public static final String NODE_FILTER_PROPERTIES_LANG = "node_filter_properties_lang";

    public static final String HISTORY_FILTER_PROPERTIES = "history_filter_properties";
    public static final String HISTORY_FILTER_PROPERTIES_LANG = "history_filter_properties_lang";

    // Set name of operation job properties
    public static final String OPERATION_JOB_PROPERTIES = "operation_job_properties";

    public static final String ACTION_DATA_REQUEST = "actionData";

    // The view with two grids
    public static final int TWO_GRID_LEFT_POSITION = 0;

    public static final int TWO_GRID_RIGHT_POSITION = 1;
    
    public static final String DATE_YYYY_MM_DD = "yyyy'/'MM'/'dd";
}
